@@ -5,14 +5,14 @@
  */
 
 #include "postpublishjob.h"
-#include "post.h"
-#include "bloggerservice.h"
 #include "account.h"
+#include "bloggerservice.h"
+#include "post.h"
 #include "utils.h"
 
-#include <QNetworkRequest>
-#include <QNetworkReply>
 #include <QNetworkAccessManager>
+#include <QNetworkReply>
+#include <QNetworkRequest>
 #include <QUrlQuery>
 
 using namespace KGAPI2;
@@ -20,11 +20,8 @@ using namespace KGAPI2::Blogger;
 
 class Q_DECL_HIDDEN PostPublishJob::Private
 {
-  public:
-    Private(const QString &blogId,
-            const QString &postId,
-            PostPublishJob::PublishAction action,
-            const QDateTime &publishDate = QDateTime());
+public:
+    Private(const QString &blogId, const QString &postId, PostPublishJob::PublishAction action, const QDateTime &publishDate = QDateTime());
 
     const QString blogId;
     const QString postId;
@@ -34,10 +31,7 @@ class Q_DECL_HIDDEN PostPublishJob::Private
     ObjectPtr response;
 };
 
-PostPublishJob::Private::Private(const QString &blogId_,
-                                 const QString &postId_,
-                                 PostPublishJob::PublishAction action_,
-                                 const QDateTime &publishDate_)
+PostPublishJob::Private::Private(const QString &blogId_, const QString &postId_, PostPublishJob::PublishAction action_, const QDateTime &publishDate_)
     : blogId(blogId_)
     , postId(postId_)
     , action(action_)
@@ -45,45 +39,30 @@ PostPublishJob::Private::Private(const QString &blogId_,
 {
 }
 
-PostPublishJob::PostPublishJob(const PostPtr &post,
-                               PublishAction action,
-                               const AccountPtr &account,
-                               QObject *parent)
+PostPublishJob::PostPublishJob(const PostPtr &post, PublishAction action, const AccountPtr &account, QObject *parent)
     : Job(account, parent)
     , d(new Private(post->blogId(), post->id(), action))
 {
 }
 
-PostPublishJob::PostPublishJob(const QString &blogId,
-                               const QString &postId,
-                               PublishAction action,
-                               const AccountPtr &account,
-                               QObject *parent)
+PostPublishJob::PostPublishJob(const QString &blogId, const QString &postId, PublishAction action, const AccountPtr &account, QObject *parent)
     : Job(account, parent)
     , d(new Private(blogId, postId, action))
 {
 }
 
-PostPublishJob::PostPublishJob(const PostPtr &post,
-                               const QDateTime &publishDate,
-                               const AccountPtr &account,
-                               QObject *parent)
+PostPublishJob::PostPublishJob(const PostPtr &post, const QDateTime &publishDate, const AccountPtr &account, QObject *parent)
     : Job(account, parent)
     , d(new Private(post->blogId(), post->id(), Publish, publishDate))
 {
 }
 
-PostPublishJob::PostPublishJob(const QString &blogId,
-                               const QString &postId,
-                               const QDateTime &publishDate,
-                               const AccountPtr &account,
-                               QObject *parent)
+PostPublishJob::PostPublishJob(const QString &blogId, const QString &postId, const QDateTime &publishDate, const AccountPtr &account, QObject *parent)
     : Job(account, parent)
     , d(new Private(blogId, postId, Publish, publishDate))
 {
 }
 
-
 PostPublishJob::~PostPublishJob()
 {
     delete d;
@@ -112,17 +91,13 @@ void PostPublishJob::start()
     enqueueRequest(request);
 }
 
-void PostPublishJob::dispatchRequest(QNetworkAccessManager *accessManager,
-                                     const QNetworkRequest &request,
-                                     const QByteArray &data,
-                                     const QString &contentType)
+void PostPublishJob::dispatchRequest(QNetworkAccessManager *accessManager, const QNetworkRequest &request, const QByteArray &data, const QString &contentType)
 {
-    Q_UNUSED(contentType);
+    Q_UNUSED(contentType)
     accessManager->post(request, data);
 }
 
-void PostPublishJob::handleReply(const QNetworkReply *reply,
-                                 const QByteArray &rawData)
+void PostPublishJob::handleReply(const QNetworkReply *reply, const QByteArray &rawData)
 {
     const QString contentType = reply->header(QNetworkRequest::ContentTypeHeader).toString();
     ContentType ct = Utils::stringToContentType(contentType);
@@ -135,5 +110,3 @@ void PostPublishJob::handleReply(const QNetworkReply *reply,
     d->response = Post::fromJSON(rawData);
     emitFinished();
 }
-
-
