@@ -7,9 +7,9 @@
  */
 
 #include "eventdeletejob.h"
-#include "calendarservice.h"
 #include "account.h"
-#include "../debug.h"
+#include "calendarservice.h"
+#include "debug.h"
 #include "event.h"
 #include "private/queuehelper_p.h"
 
@@ -19,22 +19,22 @@ using namespace KGAPI2;
 
 class Q_DECL_HIDDEN EventDeleteJob::Private
 {
-  public:
+public:
     QueueHelper<QString> eventsIds;
     QString calendarId;
 };
 
-EventDeleteJob::EventDeleteJob(const EventPtr& event, const QString &calendarId, const AccountPtr& account, QObject* parent):
-    DeleteJob(account, parent),
-    d(new Private)
+EventDeleteJob::EventDeleteJob(const EventPtr &event, const QString &calendarId, const AccountPtr &account, QObject *parent)
+    : DeleteJob(account, parent)
+    , d(new Private)
 {
     d->eventsIds << event->id();
     d->calendarId = calendarId;
 }
 
-EventDeleteJob::EventDeleteJob(const EventsList& events, const QString& calendarId, const AccountPtr& account, QObject* parent):
-    DeleteJob(account, parent),
-    d(new Private)
+EventDeleteJob::EventDeleteJob(const EventsList &events, const QString &calendarId, const AccountPtr &account, QObject *parent)
+    : DeleteJob(account, parent)
+    , d(new Private)
 {
     for (const EventPtr &event : events) {
         d->eventsIds << event->id();
@@ -42,23 +42,22 @@ EventDeleteJob::EventDeleteJob(const EventsList& events, const QString& calendar
     d->calendarId = calendarId;
 }
 
-EventDeleteJob::EventDeleteJob(const QString &eventId, const QString &calendarId, const AccountPtr &account, QObject *parent):
-    DeleteJob(account, parent),
-    d(new Private)
+EventDeleteJob::EventDeleteJob(const QString &eventId, const QString &calendarId, const AccountPtr &account, QObject *parent)
+    : DeleteJob(account, parent)
+    , d(new Private)
 {
     d->eventsIds << eventId;
     d->calendarId = calendarId;
 }
 
-EventDeleteJob::EventDeleteJob(const QStringList &eventIds, const QString &calendarId, const AccountPtr &account, QObject *parent):
-    DeleteJob(account, parent),
-    d(new Private)
+EventDeleteJob::EventDeleteJob(const QStringList &eventIds, const QString &calendarId, const AccountPtr &account, QObject *parent)
+    : DeleteJob(account, parent)
+    , d(new Private)
 {
     d->eventsIds = eventIds;
     d->calendarId = calendarId;
 }
 
-
 EventDeleteJob::~EventDeleteJob() = default;
 
 void EventDeleteJob::start()
@@ -74,12 +73,9 @@ void EventDeleteJob::start()
     enqueueRequest(request);
 }
 
-void EventDeleteJob::handleReply(const QNetworkReply* reply, const QByteArray& rawData)
+void EventDeleteJob::handleReply(const QNetworkReply *reply, const QByteArray &rawData)
 {
     d->eventsIds.currentProcessed();
 
     KGAPI2::DeleteJob::handleReply(reply, rawData);
 }
-
-
-
