@@ -6,12 +6,11 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef LIBKGAPI2_REMINDER_H
-#define LIBKGAPI2_REMINDER_H
+#pragma once
 
+#include "kgapicalendar_export.h"
 #include "object.h"
 #include "types.h"
-#include "kgapicalendar_export.h"
 
 #include <KCalendarCore/Alarm>
 #include <KCalendarCore/Incidence>
@@ -29,8 +28,7 @@ namespace KGAPI2
  */
 class KGAPICALENDAR_EXPORT Reminder
 {
-  public:
-
+public:
     /**
      * @brief Constructor
      */
@@ -42,8 +40,7 @@ class KGAPICALENDAR_EXPORT Reminder
      * @param type Type of the reminder (email, notification, etc.)
      * @param startOffset How long before the event should the reminder be shown
      */
-    explicit Reminder(const KCalendarCore::Alarm::Type &type,
-                      const KCalendarCore::Duration &startOffset = KCalendarCore::Duration(0));
+    explicit Reminder(const KCalendarCore::Alarm::Type &type, const KCalendarCore::Duration &startOffset = KCalendarCore::Duration(0));
 
     /**
      * @brief Copy constructor
@@ -87,11 +84,9 @@ class KGAPICALENDAR_EXPORT Reminder
      */
     KCalendarCore::Alarm *toAlarm(KCalendarCore::Incidence *incidence) const;
 
-  private:
+private:
     class Private;
     QScopedPointer<Private> const d;
 };
 
 } // namespace KGAPI2
-
-#endif // LIBKGAPI2_REMINDER_H
