@@ -8,12 +8,11 @@
 
 #include "authjob.h"
 #include "account.h"
-#include "../debug.h"
+#include "debug.h"
 #include "job_p.h"
 #include "private/fullauthenticationjob_p.h"
 #include "private/refreshtokensjob_p.h"
 
-
 using namespace KGAPI2;
 
 // Used by fakeauthbrowser in tests
@@ -24,7 +23,8 @@ class Q_DECL_HIDDEN AuthJob::Private
 public:
     Private(AuthJob *qq)
         : q(qq)
-    {}
+    {
+    }
 
     template<typename JobType>
     void jobFinished(Job *job)
@@ -33,7 +33,7 @@ public:
             q->setError(job->error());
             q->setErrorString(job->errorString());
         } else {
-            account = static_cast<JobType*>(job)->account();
+            account = static_cast<JobType *>(job)->account();
         }
 
         q->emitFinished();
@@ -45,12 +45,12 @@ public:
     QString username;
 
 private:
-    AuthJob * const q;
+    AuthJob *const q;
 };
 
-AuthJob::AuthJob(const AccountPtr& account, const QString &apiKey, const QString &secretKey, QObject* parent):
-    Job(parent),
-    d(new Private(this))
+AuthJob::AuthJob(const AccountPtr &account, const QString &apiKey, const QString &secretKey, QObject *parent)
+    : Job(parent)
+    , d(new Private(this))
 {
     d->account = account;
     d->apiKey = apiKey;
@@ -64,23 +64,25 @@ AccountPtr AuthJob::account() const
     return d->account;
 }
 
-void AuthJob::setUsername(const QString& username)
+void AuthJob::setUsername(const QString &username)
 {
     d->username = username;
 }
 
-void AuthJob::setPassword(const QString& /*password*/)
+void AuthJob::setPassword(const QString & /*password*/)
 {
 }
 
-void AuthJob::handleReply(const QNetworkReply * /*reply*/, const QByteArray& /*rawData*/)
+void AuthJob::handleReply(const QNetworkReply * /*reply*/, const QByteArray & /*rawData*/)
 {
     // Should never be called.
     Q_UNREACHABLE();
 }
 
-void AuthJob::dispatchRequest(QNetworkAccessManager* /*accessManager*/, const QNetworkRequest& /*request*/,
-                              const QByteArray& /*data*/, const QString& /*contentType*/)
+void AuthJob::dispatchRequest(QNetworkAccessManager * /*accessManager*/,
+                              const QNetworkRequest & /*request*/,
+                              const QByteArray & /*data*/,
+                              const QString & /*contentType*/)
 {
     // Should never be called.
     Q_UNREACHABLE();
@@ -89,23 +91,25 @@ void AuthJob::dispatchRequest(QNetworkAccessManager* /*accessManager*/, const QN
 void AuthJob::start()
 {
     if (d->account->refreshToken().isEmpty() || (d->account->m_scopesChanged == true)) {
-
         d->account->addScope(Account::accountInfoEmailScopeUrl());
 
-        auto *job = new FullAuthenticationJob(d->account, d->apiKey, d->secretKey, this);
+        auto job = new FullAuthenticationJob(d->account, d->apiKey, d->secretKey, this);
         job->setUsername(d->username);
         job->setServerPort(kgapiTcpAuthServerPort);
-        connect(job, &Job::finished, this, [this](Job *job) { d->jobFinished<FullAuthenticationJob>(job); });
+        connect(job, &Job::finished, this, [this](Job *job) {
+            d->jobFinished<FullAuthenticationJob>(job);
+        });
     } else {
-       if (d->account->accountName().isEmpty()) {
+        if (d->account->accountName().isEmpty()) {
             setError(KGAPI2::InvalidAccount);
             setErrorString(tr("Account name is empty"));
             emitFinished();
             return;
         }
 
-        auto *job = new RefreshTokensJob(d->account, d->apiKey, d->secretKey, this);
-        connect(job, &Job::finished, this, [this](Job *job) { d->jobFinished<RefreshTokensJob>(job); });
+        auto job = new RefreshTokensJob(d->account, d->apiKey, d->secretKey, this);
+        connect(job, &Job::finished, this, [this](Job *job) {
+            d->jobFinished<RefreshTokensJob>(job);
+        });
     }
 }
-
