@@ -4,16 +4,15 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef LIBKGAPI2_DRIVE_ABOUT_H
-#define LIBKGAPI2_DRIVE_ABOUT_H
+#pragma once
 
-#include "types.h"
-#include "object.h"
 #include "kgapidrive_export.h"
+#include "object.h"
+#include "types.h"
 
+#include <QSharedPointer>
 #include <QString>
 #include <QStringList>
-#include <QSharedPointer>
 #include <QUrl>
 
 namespace KGAPI2
@@ -33,9 +32,8 @@ namespace Drive
  * @author Andrius da Costa Ribas <andriusmao@gmail.com>
  * @author Daniel Vrátil <dvratil@redhat.com>
  */
-class KGAPIDRIVE_EXPORT About: public KGAPI2::Object
+class KGAPIDRIVE_EXPORT About : public KGAPI2::Object
 {
-
 public:
     /**
      * @brief DriveAbout::Format holds the structure used for importFormats[]
@@ -43,11 +41,14 @@ public:
      */
     class Format
     {
-      public:
+    public:
         explicit Format(const Format &other);
         virtual ~Format();
         bool operator==(const Format &other) const;
-        bool operator!=(const Format &other) const { return !operator==(other); }
+        bool operator!=(const Format &other) const
+        {
+            return !operator==(other);
+        }
 
         /**
          * @brief Returns the content type to convert from.
@@ -59,7 +60,7 @@ public:
          */
         QStringList targets() const;
 
-      private:
+    private:
         explicit Format();
 
         class Private;
@@ -77,19 +78,21 @@ public:
      */
     class AdditionalRoleInfo
     {
-      public:
-
+    public:
         /**
          * @brief DriveAbout::AdditionalRoleInfo::Role holds the structure used for
          *        additionalRoleInfo[].roleSets[] property.
          */
         class RoleSet
         {
-          public:
+        public:
             explicit RoleSet(const RoleSet &other);
             virtual ~RoleSet();
             bool operator==(const RoleSet &other) const;
-            bool operator!=(const RoleSet &other) const { return !operator==(other); }
+            bool operator!=(const RoleSet &other) const
+            {
+                return !operator==(other);
+            }
 
             /**
              * @brief Returns the primary permission role.
@@ -101,7 +104,7 @@ public:
              */
             QStringList additionalRoles() const;
 
-          private:
+        private:
             explicit RoleSet();
 
             class Private;
@@ -116,7 +119,10 @@ public:
         explicit AdditionalRoleInfo(const AdditionalRoleInfo &other);
         virtual ~AdditionalRoleInfo();
         bool operator==(const AdditionalRoleInfo &other) const;
-        bool operator!=(const AdditionalRoleInfo &other) const { return !operator==(other); }
+        bool operator!=(const AdditionalRoleInfo &other) const
+        {
+            return !operator==(other);
+        }
 
         /**
          * @brief Returns the content type that this additional role info applies to.
@@ -128,7 +134,7 @@ public:
          */
         RoleSetsList roleSets() const;
 
-      private:
+    private:
         explicit AdditionalRoleInfo();
 
         class Private;
@@ -145,11 +151,14 @@ public:
      */
     class Feature
     {
-      public:
+    public:
         explicit Feature(const Feature &other);
         virtual ~Feature();
         bool operator==(const Feature &other) const;
-        bool operator!=(const Feature &other) const { return !operator==(other); }
+        bool operator!=(const Feature &other) const
+        {
+            return !operator==(other);
+        }
 
         /**
          * @brief Returns the name of the feature.
@@ -161,7 +170,7 @@ public:
          */
         qreal featureRate() const;
 
-      private:
+    private:
         explicit Feature();
 
         class Private;
@@ -178,11 +187,14 @@ public:
      */
     class MaxUploadSize
     {
-      public:
+    public:
         explicit MaxUploadSize(const MaxUploadSize &other);
         virtual ~MaxUploadSize();
         bool operator==(const MaxUploadSize &other) const;
-        bool operator!=(const MaxUploadSize &other) const { return !operator==(other); }
+        bool operator!=(const MaxUploadSize &other) const
+        {
+            return !operator==(other);
+        }
 
         /**
          * @brief Returns the file type.
@@ -194,8 +206,7 @@ public:
          */
         qlonglong size() const;
 
-
-      private:
+    private:
         explicit MaxUploadSize();
 
         class Private;
@@ -259,7 +270,10 @@ public:
     ~About() override;
 
     bool operator==(const About &other) const;
-    bool operator!=(const About &other) const { return !operator==(other); }
+    bool operator!=(const About &other) const
+    {
+        return !operator==(other);
+    }
 
     /**
      * @brief Returns the link back to this item.
@@ -378,7 +392,7 @@ public:
      */
     static AboutPtr fromJSON(const QByteArray &jsonData);
 
-  private:
+private:
     About();
 
     class Private;
@@ -389,5 +403,3 @@ public:
 } /* namespace Drive */
 
 } /* namespace KGAPI2 */
-
-#endif // LIBKGAPI2_DRIVE_ABOUT_H
