@@ -6,11 +6,10 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-
 #pragma once
 
-#include "modifyjob.h"
 #include "kgapidrive_export.h"
+#include "modifyjob.h"
 
 namespace KGAPI2
 {
@@ -22,13 +21,9 @@ class KGAPIDRIVE_EXPORT PermissionModifyJob : public KGAPI2::ModifyJob
 {
     Q_OBJECT
 
-  public:
-    explicit PermissionModifyJob(const QString &fileId,
-                                 const PermissionPtr &permission,
-                                 const AccountPtr &account, QObject *parent = nullptr);
-    explicit PermissionModifyJob(const QString &fileId,
-                                 const PermissionsList &permissions,
-                                 const AccountPtr &account, QObject *parent = nullptr);
+public:
+    explicit PermissionModifyJob(const QString &fileId, const PermissionPtr &permission, const AccountPtr &account, QObject *parent = nullptr);
+    explicit PermissionModifyJob(const QString &fileId, const PermissionsList &permissions, const AccountPtr &account, QObject *parent = nullptr);
     ~PermissionModifyJob() override;
 
     /**
@@ -91,12 +86,11 @@ class KGAPIDRIVE_EXPORT PermissionModifyJob : public KGAPI2::ModifyJob
      */
     void setUseDomainAdminAccess(bool useDomainAdminAccess);
 
-  protected:
+protected:
     void start() override;
-    KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-            const QByteArray &rawData) override;
+    KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData) override;
 
-  private:
+private:
     class Private;
     QScopedPointer<Private> d;
     friend class Private;
@@ -105,4 +99,3 @@ class KGAPIDRIVE_EXPORT PermissionModifyJob : public KGAPI2::ModifyJob
 } // namespace Drive
 
 } // namespace KGAPI2
-
