@@ -5,13 +5,12 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI2_DRIVE_SEARCHQUERY_H
-#define KGAPI2_DRIVE_SEARCHQUERY_H
+#pragma once
 
 #include "kgapidrive_export.h"
 
-#include <QVariant>
 #include <QSharedDataPointer>
+#include <QVariant>
 
 namespace KGAPI2
 {
@@ -24,22 +23,9 @@ namespace Drive
 class KGAPIDRIVE_EXPORT SearchQuery
 {
 public:
-    enum CompareOperator {
-        Contains,
-        Equals,
-        NotEquals,
-        Less,
-        LessOrEqual,
-        Greater,
-        GreaterOrEqual,
-        In,
-        Has
-    };
+    enum CompareOperator { Contains, Equals, NotEquals, Less, LessOrEqual, Greater, GreaterOrEqual, In, Has };
 
-    enum LogicOperator {
-        And,
-        Or
-    };
+    enum LogicOperator { And, Or };
 
     SearchQuery(LogicOperator op = And);
     SearchQuery(const SearchQuery &other);
@@ -54,11 +40,9 @@ public:
 
     QString serialize() const;
 
-  private:
+private:
     class Private;
     QSharedDataPointer<Private> d;
 };
 }
 }
-
-#endif // KGAPI2_DRIVE_SEARCHQUERY_H
