@@ -6,11 +6,10 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-
 #include "teamdrivedeletejob.h"
-#include "teamdrive.h"
 #include "account.h"
 #include "driveservice.h"
+#include "teamdrive.h"
 
 #include <QNetworkRequest>
 
@@ -19,40 +18,36 @@ using namespace KGAPI2::Drive;
 
 class Q_DECL_HIDDEN TeamdriveDeleteJob::Private
 {
-  public:
+public:
     QStringList teamdrivesIds;
 };
 
-TeamdriveDeleteJob::TeamdriveDeleteJob(const QString &teamdriveId,
-                                         const AccountPtr &account, QObject *parent):
-    DeleteJob(account, parent),
-    d(new Private)
+TeamdriveDeleteJob::TeamdriveDeleteJob(const QString &teamdriveId, const AccountPtr &account, QObject *parent)
+    : DeleteJob(account, parent)
+    , d(new Private)
 {
     d->teamdrivesIds << teamdriveId;
 }
 
-TeamdriveDeleteJob::TeamdriveDeleteJob(const QStringList &teamdrivesIds,
-                                         const AccountPtr &account, QObject *parent):
-    DeleteJob(account, parent),
-    d(new Private)
+TeamdriveDeleteJob::TeamdriveDeleteJob(const QStringList &teamdrivesIds, const AccountPtr &account, QObject *parent)
+    : DeleteJob(account, parent)
+    , d(new Private)
 {
     d->teamdrivesIds << teamdrivesIds;
 }
 
-TeamdriveDeleteJob::TeamdriveDeleteJob(const TeamdrivePtr &teamdrive,
-                                         const AccountPtr &account, QObject *parent):
-    DeleteJob(account, parent),
-    d(new Private)
+TeamdriveDeleteJob::TeamdriveDeleteJob(const TeamdrivePtr &teamdrive, const AccountPtr &account, QObject *parent)
+    : DeleteJob(account, parent)
+    , d(new Private)
 {
     d->teamdrivesIds << teamdrive->id();
 }
 
-TeamdriveDeleteJob::TeamdriveDeleteJob(const TeamdrivesList &teamdrives,
-                                         const AccountPtr &account, QObject *parent):
-    DeleteJob(account, parent),
-    d(new Private)
+TeamdriveDeleteJob::TeamdriveDeleteJob(const TeamdrivesList &teamdrives, const AccountPtr &account, QObject *parent)
+    : DeleteJob(account, parent)
+    , d(new Private)
 {
-    for (const TeamdrivePtr & teamdrive : std::as_const(teamdrives)) {
+    for (const TeamdrivePtr &teamdrive : std::as_const(teamdrives)) {
         d->teamdrivesIds << teamdrive->id();
     }
 }
@@ -72,5 +67,3 @@ void TeamdriveDeleteJob::start()
     QNetworkRequest request(url);
     enqueueRequest(request);
 }
-
-
