@@ -6,14 +6,13 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-
 #include "taskdeletejob.h"
-#include "tasksservice.h"
 #include "account.h"
 #include "debug.h"
-#include "task.h"
-#include "utils.h"
 #include "private/queuehelper_p.h"
+#include "task.h"
+#include "tasksservice.h"
+#include "utils.h"
 
 #include <QNetworkRequest>
 
@@ -21,24 +20,22 @@ using namespace KGAPI2;
 
 class Q_DECL_HIDDEN TaskDeleteJob::Private
 {
-  public:
+public:
     QueueHelper<QString> tasksIds;
     QString taskListId;
 };
 
-TaskDeleteJob::TaskDeleteJob(const TaskPtr& task, const QString& taskListId,
-                             const AccountPtr& account, QObject* parent):
-    DeleteJob(account, parent),
-    d(new Private())
+TaskDeleteJob::TaskDeleteJob(const TaskPtr &task, const QString &taskListId, const AccountPtr &account, QObject *parent)
+    : DeleteJob(account, parent)
+    , d(new Private())
 {
     d->tasksIds << task->uid();
     d->taskListId = taskListId;
 }
 
-TaskDeleteJob::TaskDeleteJob(const TasksList& tasks, const QString& tasklistId,
-                             const AccountPtr& account, QObject* parent):
-    DeleteJob(account, parent),
-    d(new Private())
+TaskDeleteJob::TaskDeleteJob(const TasksList &tasks, const QString &tasklistId, const AccountPtr &account, QObject *parent)
+    : DeleteJob(account, parent)
+    , d(new Private())
 {
     d->tasksIds.reserve(tasks.size());
     for (const TaskPtr &task : std::as_const(tasks)) {
@@ -47,19 +44,17 @@ TaskDeleteJob::TaskDeleteJob(const TasksList& tasks, const QString& tasklistId,
     d->taskListId = tasklistId;
 }
 
-TaskDeleteJob::TaskDeleteJob(const QString &taskId, const QString &taskListId,
-                             const AccountPtr &account, QObject *parent):
-    DeleteJob(account, parent),
-    d(new Private())
+TaskDeleteJob::TaskDeleteJob(const QString &taskId, const QString &taskListId, const AccountPtr &account, QObject *parent)
+    : DeleteJob(account, parent)
+    , d(new Private())
 {
     d->tasksIds << taskId;
     d->taskListId = taskListId;
 }
 
-TaskDeleteJob::TaskDeleteJob(const QStringList &tasksIds, const QString &taskListId,
-                             const AccountPtr &account, QObject *parent):
-    DeleteJob(account, parent),
-    d(new Private())
+TaskDeleteJob::TaskDeleteJob(const QStringList &tasksIds, const QString &taskListId, const AccountPtr &account, QObject *parent)
+    : DeleteJob(account, parent)
+    , d(new Private())
 {
     d->tasksIds = tasksIds;
     d->taskListId = taskListId;
@@ -81,11 +76,9 @@ void TaskDeleteJob::start()
     enqueueRequest(request);
 }
 
-void TaskDeleteJob::handleReply(const QNetworkReply* reply, const QByteArray& rawData)
+void TaskDeleteJob::handleReply(const QNetworkReply *reply, const QByteArray &rawData)
 {
     d->tasksIds.currentProcessed();
 
     KGAPI2::DeleteJob::handleReply(reply, rawData);
 }
-
-
